@@ -4,8 +4,11 @@ from .utils import *
 
 
 def safe_json_dumps(obj):
-    if isinstance(obj, dict):
-        obj = json.dumps(obj)
+    try:
+        if isinstance(obj, dict):
+            obj = json.dumps(obj)
+    except:
+        pass
     return obj
 
 async def async_make_request(url, payload, headers=None):
@@ -174,7 +177,7 @@ def make_request(url=None, payload={}, headers=None, url_1_only=None, url_2_only
         elif (not url_1_only and url_2_only) or (url_1_only and url_2_only):
             url = fall_back_rpc
     url = url or solana_rpc_url
-    return get_async_response(async_make_reques,url=url,payload=payload,headers=headers or get_headers())
+    return get_async_response(async_make_request,url=url,payload=payload,headers=headers or get_headers())
 def call_rate_limiter(method, params, url_1_only=True, url_2_only=False,*args, **kwargs):
     return get_async_response(async_call_rate_limiter,method=method, params=params, url_1_only=url_1_only, url_2_only=url_2_only,*args, **kwargs)
 
